"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ReadiumView = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _hooks = require("./hooks");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const ReadiumView = /*#__PURE__*/_react.default.forwardRef((_ref, ref) => {
  let {
    file,
    settings,
    location,
    onLocationChange,
    onTableOfContents,
    style = {},
    height,
    width
  } = _ref;
  const readerRef = (0, _hooks.useReaderRef)({
    file,
    onLocationChange,
    onTableOfContents
  });
  const reader = readerRef.current;
  (0, _react.useImperativeHandle)(ref, () => ({
    nextPage: () => {
      var _readerRef$current;

      (_readerRef$current = readerRef.current) === null || _readerRef$current === void 0 ? void 0 : _readerRef$current.nextPage();
    },
    prevPage: () => {
      var _readerRef$current2;

      (_readerRef$current2 = readerRef.current) === null || _readerRef$current2 === void 0 ? void 0 : _readerRef$current2.previousPage();
    }
  }));
  (0, _hooks.useSettingsObserver)(reader, settings);
  (0, _hooks.useLocationObserver)(reader, location);
  const mainStyle = { ...styles.maximize,
    ...style
  };
  if (height) mainStyle.height = height;
  if (width) mainStyle.width = width;
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.container
  }, !reader && /*#__PURE__*/_react.default.createElement("div", {
    style: styles.loader
  }, "Loading reader..."), /*#__PURE__*/_react.default.createElement("div", {
    id: "D2Reader-Container",
    style: styles.d2Container
  }, /*#__PURE__*/_react.default.createElement("main", {
    style: mainStyle,
    tabIndex: -1,
    id: "iframe-wrapper"
  }, /*#__PURE__*/_react.default.createElement("div", {
    id: "reader-loading",
    className: "loading",
    style: styles.loader
  }), /*#__PURE__*/_react.default.createElement("div", {
    id: "reader-error",
    className: "error"
  }))));
});

exports.ReadiumView = ReadiumView;

const styles = _reactNative.StyleSheet.create({
  container: {
    width: '100%',
    height: '100%'
  },
  d2Container: {
    width: '100%',
    height: '100%',
    display: 'flex'
  },
  maximize: {
    width: '100%',
    height: '100%',
    display: 'flex'
  },
  button: {
    width: 50,
    fontSize: 100,
    backgroundColor: 'transparent',
    border: 'none'
  },
  loader: {
    width: '100%',
    height: '100%',
    textAlign: 'center',
    position: 'relative',
    top: 'calc(50% - 10px)'
  }
});
//# sourceMappingURL=ReadiumView.js.map