import React, { useImperativeHandle } from 'react';
import { View, StyleSheet } from 'react-native';
import { useReaderRef, useSettingsObserver, useLocationObserver } from './hooks';
export const ReadiumView = /*#__PURE__*/React.forwardRef((_ref, ref) => {
  let {
    file,
    settings,
    location,
    onLocationChange,
    onTableOfContents,
    style = {},
    height,
    width
  } = _ref;
  const readerRef = useReaderRef({
    file,
    onLocationChange,
    onTableOfContents
  });
  const reader = readerRef.current;
  useImperativeHandle(ref, () => ({
    nextPage: () => {
      var _readerRef$current;

      (_readerRef$current = readerRef.current) === null || _readerRef$current === void 0 ? void 0 : _readerRef$current.nextPage();
    },
    prevPage: () => {
      var _readerRef$current2;

      (_readerRef$current2 = readerRef.current) === null || _readerRef$current2 === void 0 ? void 0 : _readerRef$current2.previousPage();
    }
  }));
  useSettingsObserver(reader, settings);
  useLocationObserver(reader, location);
  const mainStyle = { ...styles.maximize,
    ...style
  };
  if (height) mainStyle.height = height;
  if (width) mainStyle.width = width;
  return /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, !reader && /*#__PURE__*/React.createElement("div", {
    style: styles.loader
  }, "Loading reader..."), /*#__PURE__*/React.createElement("div", {
    id: "D2Reader-Container",
    style: styles.d2Container
  }, /*#__PURE__*/React.createElement("main", {
    style: mainStyle,
    tabIndex: -1,
    id: "iframe-wrapper"
  }, /*#__PURE__*/React.createElement("div", {
    id: "reader-loading",
    className: "loading",
    style: styles.loader
  }), /*#__PURE__*/React.createElement("div", {
    id: "reader-error",
    className: "error"
  }))));
});
const styles = StyleSheet.create({
  container: {
    width: '100%',
    height: '100%'
  },
  d2Container: {
    width: '100%',
    height: '100%',
    display: 'flex'
  },
  maximize: {
    width: '100%',
    height: '100%',
    display: 'flex'
  },
  button: {
    width: 50,
    fontSize: 100,
    backgroundColor: 'transparent',
    border: 'none'
  },
  loader: {
    width: '100%',
    height: '100%',
    textAlign: 'center',
    position: 'relative',
    top: 'calc(50% - 10px)'
  }
});
//# sourceMappingURL=ReadiumView.js.map